BenchmarkReport class

Performance benchmark report for AI model inference.

Constructors

BenchmarkReport({required String modelId, required List<double> inferenceTimes, required List<double> memoryUsages, required int numRuns, DateTime? timestamp})
Constructs a BenchmarkReport.
BenchmarkReport.fromJson(Map<String, dynamic> json)
Constructs a BenchmarkReport from a JSON map.
factory

Properties

avg double
Calculates the average (mean) value.
no setter
hashCode int
The hash code for this object.
no setterinherited
inferenceTimes List<double>
List of recorded inference times (in milliseconds).
final
max double
Calculates the maximum value.
no setter
memoryAvg double
Average memory usage.
no setter
memoryMax double
Maximum memory usage.
no setter
memoryMin double
Minimum memory usage.
no setter
memoryP50 double
Memory usage stats.
no setter
memoryP90 double
Memory usage p90.
no setter
memoryP99 double
Memory usage p99.
no setter
memoryUsages List<double>
List of recorded memory usages (in MB).
final
min double
Calculates the minimum value.
no setter
modelId String
Model identifier under test.
final
numRuns int
Number of benchmark runs completed.
final
p50 double
Calculates the p50 (median) percentile.
no setter
p90 double
Calculates the p90 percentile.
no setter
p99 double
Calculates the p99 percentile.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stdDev double
Calculates the standard deviation.
no setter
timestamp DateTime
Timestamp when the benchmark run completed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Generates a JSON representation.
toMarkdown() String
Generates a Markdown report.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

reduceMax(double a, double b) double
Helper for reduce max.
reduceMin(double a, double b) double
Helper for reduce min.