Failure class

Records an unexpected exception that prevented a fault cycle from running.

Constructors

Failure({required FaultType injectorType, required String message, StackTrace? stackTrace})
Constructs a Failure.
const
Failure.fromJson(Map<String, dynamic> json)
Deserialises from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
injectorType FaultType
The fault type whose injector threw the exception.
final
message String
The exception message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
Stack trace, if captured.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialises to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited