ModelFactory class

Factory for creating model adapters based on detected file types.

Constructors

ModelFactory()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create({required String filePath, required String modelId, bool autoDetect = true, Uint8List? modelBytes}) → AIModelAdapter
Creates an adapter for the given file path.