FinishedEvent class
Event emitted when the test finishes.
- Inheritance
-
- Object
- StressEvent
- FinishedEvent
Constructors
- FinishedEvent({required bool passed, required int totalTests, required int passedCount, required int failedCount, required int durationMs})
- Constructs a FinishedEvent.
Properties
- durationMs → int
-
Total test duration in milliseconds.
final
- failedCount → int
-
Number of tests failed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- passed → bool
-
Overall pass/fail status.
final
- passedCount → int
-
Number of tests passed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
Timestamp when the event occurred.
finalinherited
- totalTests → int
-
Total number of tests run.
final
- type → StressEventType
-
The type of stress event.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the event to a JSON map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited