InjectorErrorEvent class
Event emitted when an injector errors.
- Inheritance
-
- Object
- StressEvent
- InjectorErrorEvent
Constructors
- InjectorErrorEvent({required String injectorName, required String error})
- Constructs an InjectorErrorEvent.
Properties
- error → String
-
Error string description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- injectorName → String
-
Name of the injector that errored.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
Timestamp when the event occurred.
finalinherited
- type → StressEventType
-
The type of stress event.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the event to a JSON map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited