MetricDiff class

Represents a difference between two reports for a single metric.

Constructors

MetricDiff({required String metric, required String before, required String after, required DiffStatus status, required String message})
Constructs a MetricDiff.

Properties

after String
Value string after change.
final
before String
Value string before change.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable explanation of the difference.
final
metric String
Name of the metric being compared.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status DiffStatus
Status of the diff (same, changed, added, removed).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialises to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited