ReportDiff class
Result of comparing two stress reports.
Constructors
-
ReportDiff({required StressReport report1, required StressReport report2, required List<
MetricDiff> diffs, required int totalDiffs, required bool hasChanges, required double tolerancePercent}) - Constructs a ReportDiff.
Properties
-
diffs
→ List<
MetricDiff> -
List of individual metric differences.
final
- hasChanges → bool
-
Whether any meaningful changes were detected beyond tolerance.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- report1 → StressReport
-
Baseline / previous stress report.
final
- report2 → StressReport
-
Current / new stress report.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tolerancePercent → double
-
Tolerance percentage applied when comparing metrics.
final
- totalDiffs → int
-
Total count of differences found.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toHtml(
) → String - Generates HTML for the diff report.
-
toMarkdown(
) → String - Generates a Markdown summary of the diff.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited