StartedEvent class
Event emitted when the test starts.
- Inheritance
-
- Object
- StressEvent
- StartedEvent
Constructors
-
StartedEvent({required String modelId, required List<
String> injectorNames, required int totalInjectors}) - Constructs a StartedEvent.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
injectorNames
→ List<
String> -
Names of injectors to be run.
final
- modelId → String
-
ID of the model being tested.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
Timestamp when the event occurred.
finalinherited
- totalInjectors → int
-
Total count of injectors.
final
- type → StressEventType
-
The type of stress event.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the event to a JSON map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited