SateAI class
Top-level convenience API for running SATE AI stress tests (CLI edition).
Identical to SateAI in the main library but importable without the
Flutter SDK, making it suitable for dart run CLI tools and CI scripts.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
stress(
{required AIModelAdapter model, required List< FaultInjector> injectors, Duration timeout = const Duration(seconds: 30)}) → Future<StressReport> -
Runs a stress test against
modelusing each of theinjectors.